--- layout: template title: API - pyatv.conf permalink: /api/conf/ link_group: api ---

# Module `pyatv.conf`

Configuration used when connecting to a device.

A configuration describes a device, e.g. it's name, IP address and credentials. It is possible to manually create a configuration, but generally scanning for devices will provide configurations for you.

Browse git

## Classes

`class AirPlayService (identifier: Optional[str], port: int = 7000, credentials: Optional[str] = None, properties: Optional[Mapping[str, str]] = None)`

  Representation of an AirPlay service.

  DEPRECATED: Use `ManualService` instead.

  Initialize a new AirPlayService.

  Browse git

  ### Ancestors

  - ManualService
  - BaseService
  - abc.ABC

  ### Inherited members

  - `ManualService`:
    - `apply`
    - `enabled`
    - `identifier`
    - `merge`
    - `pairing`
    - `port`
    - `properties`
    - `protocol`
    - `requires_password`
    - `settings`
`class AppleTV (address: ipaddress.IPv4Address, name: str, deep_sleep: bool = False, properties: Optional[Mapping[str, Mapping[str, str]]] = None, device_info: Optional[DeviceInfo] = None)`

  Representation of a device configuration.

  An instance of this class represents a single device. A device can have several services depending on the protocols it supports, e.g. DMAP or AirPlay.

  Initialize a new AppleTV.

  Browse git

  ### Ancestors

  - BaseConfig
  - abc.ABC

  ### Inherited members

  - `BaseConfig`:
    - `add_service`
    - `address`
    - `all_identifiers`
    - `apply`
    - `deep_sleep`
    - `device_info`
    - `get_service`
    - `identifier`
    - `main_service`
    - `name`
    - `properties`
    - `ready`
    - `services`
    - `set_credentials`
`class CompanionService (port: int, credentials: Optional[str] = None, properties: Optional[Mapping[str, str]] = None)`

  Representation of a Companion link service.

  DEPRECATED: Use `ManualService` instead.

  Initialize a new CompaniomService.

  Browse git

  ### Ancestors

  - ManualService
  - BaseService
  - abc.ABC

  ### Inherited members

  - `ManualService`:
    - `apply`
    - `enabled`
    - `identifier`
    - `merge`
    - `pairing`
    - `port`
    - `properties`
    - `protocol`
    - `requires_password`
    - `settings`
`class DmapService (identifier: Optional[str], credentials: Optional[str], port: int = 3689, properties: Optional[Mapping[str, str]] = None)`

  Representation of a DMAP service.

  DEPRECATED: Use `ManualService` instead.

  Initialize a new DmapService.

  Browse git

  ### Ancestors

  - ManualService
  - BaseService
  - abc.ABC

  ### Inherited members

  - `ManualService`:
    - `apply`
    - `enabled`
    - `identifier`
    - `merge`
    - `pairing`
    - `port`
    - `properties`
    - `protocol`
    - `requires_password`
    - `settings`
`class ManualService (identifier: Optional[str], protocol: Protocol, port: int, properties: Optional[Mapping[str, str]], credentials: Optional[str] = None, password: Optional[str] = None, requires_password: bool = False, pairing_requirement: PairingRequirement = PairingRequirement.Unsupported, enabled: bool = True)`

  Service used when manually creating and adding a service.

  Initialize a new ManualService.

  Browse git

  ### Ancestors

  - BaseService
  - abc.ABC

  ### Subclasses

  - AirPlayService
  - CompanionService
  - DmapService
  - MrpService
  - RaopService

  ### Inherited members

  - `BaseService`:
    - `apply`
    - `enabled`
    - `identifier`
    - `merge`
    - `pairing`
    - `port`
    - `properties`
    - `protocol`
    - `requires_password`
    - `settings`
`class MrpService (identifier: Optional[str], port: int, credentials: Optional[str] = None, properties: Optional[Mapping[str, str]] = None)`

  Representation of a MediaRemote Protocol (MRP) service.

  DEPRECATED: Use `ManualService` instead.

  Initialize a new MrpService.

  Browse git

  ### Ancestors

  - ManualService
  - BaseService
  - abc.ABC

  ### Inherited members

  - `ManualService`:
    - `apply`
    - `enabled`
    - `identifier`
    - `merge`
    - `pairing`
    - `port`
    - `properties`
    - `protocol`
    - `requires_password`
    - `settings`
`class RaopService (identifier: Optional[str], port: int = 7000, credentials: Optional[str] = None, password: Optional[str] = None, properties: Optional[Mapping[str, str]] = None)`

  Representation of an RAOP service.

  DEPRECATED: Use `ManualService` instead.

  Initialize a new RaopService.

  Browse git

  ### Ancestors

  - ManualService
  - BaseService
  - abc.ABC

  ### Inherited members

  - `ManualService`:
    - `apply`
    - `enabled`
    - `identifier`
    - `merge`
    - `pairing`
    - `port`
    - `properties`
    - `protocol`
    - `requires_password`
    - `settings`